/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014 Red Hat, Inc., and individual contributors
 * as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wildfly.security.sasl.util;

import javax.security.sasl.SaslClient;
import javax.security.sasl.SaslServer;

/**
 * Utility methods for SASL wrappers.
 *
 * @author <a href="mailto:david.lloyd@redhat.com">David M. Lloyd</a>
 */
public final class SaslWrappers {

    private SaslWrappers() {
    }

    /**
     * Get a wrapper for the given SASL client.
     *
     * @param saslClient the SASL client
     * @return the SASL wrapper
     */
    public static SaslWrapper wrapperFor(SaslClient saslClient) {
        return saslClient instanceof SaslWrapper ? (SaslWrapper) saslClient : new ClientSaslWrapper(saslClient);
    }

    /**
     * Get a wrapper for the given SASL server.
     *
     * @param saslServer the SASL server
     * @return the SASL wrapper
     */
    public static SaslWrapper wrapperFor(SaslServer saslServer) {
        return saslServer instanceof SaslWrapper ? (SaslWrapper) saslServer : new ServerSaslWrapper(saslServer);
    }
}
